summaryrefslogtreecommitdiff
path: root/internal/http/http.go
diff options
context:
space:
mode:
authorjwijenbergh <jeroenwijenbergh@protonmail.com>2023-01-12 21:37:38 +0100
committerjwijenbergh <jeroenwijenbergh@protonmail.com>2023-01-12 21:37:38 +0100
commit1f188da1f97e05451208f7f9d2337066b77a8368 (patch)
treeece869936f4d376630bd6fe3e7ad47b811d2cfc7 /internal/http/http.go
parent724b305dcb57ccbaa13b476d08a03c32ccd1b4ed (diff)
HTTP: Set default timeout to 10 seconds
Diffstat (limited to 'internal/http/http.go')
-rw-r--r--internal/http/http.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/http/http.go b/internal/http/http.go
index 2512b40..32316c6 100644
--- a/internal/http/http.go
+++ b/internal/http/http.go
@@ -82,8 +82,8 @@ type Client struct {
// Returns a HTTP client with some default settings
func NewClient() *Client {
- // The timeout is 5 seconds by default
- c := &http.Client{Timeout: 5 * time.Second}
+ // The timeout is 10 seconds by default
+ c := &http.Client{Timeout: 10 * time.Second}
// ReadLimit denotes the maximum amount of bytes that are read in HTTP responses
// This is used to prevent servers from sending huge amounts of data
// A limit of 16MB, although maybe much larger than needed, ensures that we do not run into problems